@@ -1,5 +1,8 @@
 import os
 
+from crispy_forms.compatibility import text_type
+
+
 BASE_DIR = os.path.dirname(__file__)
 
 INSTALLED_APPS = (
@@ -27,12 +30,14 @@ ROOT_URLCONF = 'urls'
 CRISPY_TEMPLATE_PACK = 'bootstrap'
 CRISPY_CLASS_CONVERTERS = {"textinput": "textinput textInput inputtext"}
 SECRET_KEY = 'secretkey'
+SITE_ROOT = os.path.dirname(os.path.abspath(__file__))
+
 
 # http://djangosnippets.org/snippets/646/
 class InvalidVarException(object):
     def __mod__(self, missing):
         try:
-            missing_str = unicode(missing)
+            missing_str = text_type(missing)
         except:
             missing_str = 'Failed to create string representation'
         raise Exception('Unknown template variable %r %s' % (missing, missing_str))
