@@ -13,7 +13,6 @@ from django.template import loader
 from django.middleware.csrf import _get_new_csrf_key
 from django.shortcuts import render_to_response
 from django.test import TestCase, RequestFactory
-from django.test.utils import override_settings
 from django.utils.translation import ugettext_lazy as _
 
 from crispy_forms.compatibility import string_types, text_type
@@ -37,6 +36,7 @@ from crispy_forms.tests.forms import (
     TestForm, TestForm2, TestForm3, ExampleForm, CheckboxesTestForm,
     FormWithMeta, TestForm4, CrispyTestModel
 )
+from crispy_forms.tests.utils import override_settings
 
 
 class CrispyTestCase(TestCase):
@@ -733,6 +733,7 @@ class TestFormLayout(CrispyTestCase):
         html = render_crispy_form(form)
         self.assertEqual(html.count("<input"), 5)
         self.assertEqual(html.count('type="hidden"'), 5)
+        self.assertEqual(html.count('<label'), 0)
 
     def test_field_with_buttons(self):
         form = TestForm()
@@ -813,6 +814,7 @@ class TestFormLayout(CrispyTestCase):
         self.assertTrue('title="fieldset_title"' in html)
         self.assertTrue('test-fieldset="123"' in html)
         self.assertTrue('id="row_passwords"' in html)
+        self.assertEqual(html.count('<label'), 6)
 
         if self.current_template_pack == 'uni_form':
             self.assertTrue('class="formRow rows"' in html)
